@@ -1,19 +1,21 @@
 from dataclasses import dataclass
-from typing import Optional
+from typing import *
 
 from dataclasses_json import dataclass_json
 
-from .fields import default
+from .enum import AccountType
+from .fields import default, account_type_field
 from .user_stats import UserStats
 
 
 @dataclass_json
 @dataclass
 class UserDetail:
-    avatar: str = default()
-    hash: str = default()
     id: int = default()
     name: str = default()
-    stats: Optional[UserStats] = default()
+    unique_set: bool = default("uniqueSet")
+    hash: Optional[str] = default()
     testplay: Optional[bool] = default()
-
+    avatar: str = default()
+    stats: Optional[UserStats] = default()
+    type: AccountType = account_type_field()
